xf86-video-ati: Branch 'master'

Alex Deucher agd5f at kemper.freedesktop.org
Thu Nov 6 12:47:37 PST 2008


 src/radeon_bios.c |    6 ++----
 1 file changed, 2 insertions(+), 4 deletions(-)

New commits:
commit 902eaf768142c6c7dcc487e10775027b84cd1f9a
Author: Alex Deucher <alexdeucher at gmail.com>
Date:   Thu Nov 6 15:46:43 2008 -0500

    Check for LVDS on all IGP chips
    
    - fixes bug 18395

diff --git a/src/radeon_bios.c b/src/radeon_bios.c
index 22bb5ed..89c816c 100644
--- a/src/radeon_bios.c
+++ b/src/radeon_bios.c
@@ -615,10 +615,8 @@ static Bool RADEONGetLegacyConnectorInfoFromBIOS (ScrnInfoPtr pScrn)
     }
 
     /* check LVDS table */
-    /* RS4xx can be mobile or desktop so check the connectors */
-    if (info->IsMobility ||
-	info->ChipFamily == CHIP_FAMILY_RS400 ||
-	info->ChipFamily == CHIP_FAMILY_RS480) {
+    /* IGP can be mobile or desktop so check the connectors */
+    if (info->IsMobility || info->IsIGP) {
 	offset = RADEON_BIOS16(info->ROMHeaderStart + 0x40);
 	if (offset) {
 	    info->BiosConnector[4].valid = TRUE;


More information about the xorg-commit mailing list